Thread (55 messages) 55 messages, 2 authors, 2019-05-06
STALE2594d
Revisions (4)
  1. v2 current
  2. v3 [diff vs current]
  3. v6 [diff vs current]
  4. v7 [diff vs current]

[PATCH v2 06/36] mtd: nand: Rename a core structure

From: Miquel Raynal <miquel.raynal@bootlin.com>
Date: 2019-03-04 22:31:16
Subsystem: memory technology devices (mtd), nand flash subsystem, the rest · Maintainers: Miquel Raynal, Richard Weinberger, Vignesh Raghavendra, Linus Torvalds

Prepare the migration to a generic ECC engine by renaming the
nand_ecc_req structure into nand_ecc_conf. This structure will be the
base of a wider 'nand_ecc' structure.

Signed-off-by: Miquel Raynal <miquel.raynal@bootlin.com>
---
 include/linux/mtd/nand.h    | 8 ++++----
 include/linux/mtd/spinand.h | 2 +-
 2 files changed, 5 insertions(+), 5 deletions(-)
diff --git a/include/linux/mtd/spinand.h b/include/linux/mtd/spinand.h
index b92e2aa955b6..3008de54f958 100644
--- a/include/linux/mtd/spinand.h
+++ b/include/linux/mtd/spinand.h
@@ -263,7 +263,7 @@ struct spinand_info {
 	u8 devid;
 	u32 flags;
 	struct nand_memory_organization memorg;
-	struct nand_ecc_req eccreq;
+	struct nand_ecc_conf eccreq;
 	struct spinand_ecc_info eccinfo;
 	struct {
 		const struct spinand_op_variants *read_cache;
diff --git a/include/linux/mtd/nand.h b/include/linux/mtd/nand.h
index 84ab76f34c74..78cf905083c9 100644
--- a/include/linux/mtd/nand.h
+++ b/include/linux/mtd/nand.h
@@ -123,11 +123,11 @@ struct nand_page_io_req {
 };
 
 /**
  * struct nand_ecc_req - NAND ECC requirements
  * @strength: ECC strength
- * @step_size: ECC step/block size
+ * @step_size: Number of bytes per step
  */
-struct nand_ecc_req {
+struct nand_ecc_conf {
 	unsigned int strength;
 	unsigned int step_size;
 };
@@ -186,7 +186,7 @@ struct nand_ops {
 struct nand_device {
 	struct mtd_info mtd;
 	struct nand_memory_organization memorg;
-	struct nand_ecc_req eccreq;
+	struct nand_ecc_conf eccreq;
 	struct nand_row_converter rowconv;
 	struct nand_bbt bbt;
 	const struct nand_ops *ops;
@@ -123,11 +123,11 @@ struct nand_page_io_req {
 
 /**
- * struct nand_ecc_req - NAND ECC requirements
+ * struct nand_ecc_conf - NAND ECC configuration
  * @strength: ECC strength
-- 
2.19.1


_______________________________________________
linux-arm-kernel mailing list
linux-arm-kernel@lists.infradead.org
http://lists.infradead.org/mailman/listinfo/linux-arm-kernel
Keyboard shortcuts
hback out one level
jnext message in thread
kprevious message in thread
ldrill in
Escclose help / fold thread tree
?toggle this help